pixie16 package
===============

The package consists of several modules and subpackages, as well as, as a few executables.

Executables
-----------

The following programs are included in pypixie16:

.. toctree::
   :maxdepth: 1

   pixie16-binary-browser
   pixie16-parameter-scan
   pixie16-coincidence

Submodules
----------

.. toctree::
   :maxdepth: 4

   pixie16.c-library-sdk
   pixie16.analyze
   pixie16.config
   pixie16.control
   pixie16.plot
   pixie16.scan
   pixie16.pipeline
   pixie16.tasks

Subpackages
-----------

Currently there are two subpackages for reading binary data such as
list mode data and settings data and another package for UI elements
that are used in the Qt-based interfaces provided to, for example,
look at binary data files.

.. toctree::
   :maxdepth: 4

   pixie16.read
   pixie16.ui

